@@ -26,6 +26,7 @@ class BasePlayer(gtk.Object):
     replaygain_profiles = [None, None, ["none"]]
     _length = 1
     _volume = 1.0
+    _eq_values = []
 
     _gsignals_ = {
         'song-started':
@@ -45,6 +46,8 @@ class BasePlayer(gtk.Object):
                    0.0, 1.0, 1.0, gobject.PARAM_READWRITE)
         }
 
+
+
     def __init__(self, *args, **kwargs):
         super(BasePlayer, self).__init__()
 
@@ -73,7 +76,8 @@ class BasePlayer(gtk.Object):
 
     def remove(self, song):
         if self.song is song:
-            self._end(False)
+            self._source.next()
+            self._end(True)
 
     def stop(self):
         self.paused = True
@@ -103,7 +107,31 @@ class BasePlayer(gtk.Object):
         if self.song:
             self.paused = False
 
-    def go_to(self, song):
+    def go_to(self, song, explicit=False):
         print_d("Going to %r" % song, context=self)
-        self._source.go_to(song)
+        res = self._source.go_to(song, explicit)
+        if explicit and not res:
+            return False
         self._end(True)
+        return self.song is not None
+
+    @property
+    def eq_bands(self):
+        """
+        A read-only list of equalizer bands (in Hz) supported by this backend.
+        """
+        # For backwards compatibility, do a hasattr() before calling this.
+        return []
+
+    def _get_eq_values(self):
+        """
+        The list of equalizer values, in the range (-24dB, 12dB).
+        """
+        return self._eq_values
+
+    def _set_eq_values(self, value):
+        self._eq_values[:] = value
+        if hasattr(self, 'update_eq_values'):
+            self.update_eq_values()
+
+    eq_values = property(_get_eq_values,_set_eq_values)
