@@ -441,7 +441,7 @@ class EditTags(gtk.VBox):
         if not replaced: row[EDITED] = row[DELETED] = True
 
     def __popup_menu(self, view, parent):
-        menu = gtk.Menu()        
+        menu = gtk.Menu()
         spls = config.get("editing", "split_on").decode(
             'utf-8', 'replace').split()
 
@@ -457,7 +457,9 @@ class EditTags(gtk.VBox):
         if len(rows) == 1:
             row = model[rows[0]]
 
-            text = util.unescape(row[VALUE].decode('utf-8'))
+            value = row[VALUE].decode('utf-8')
+            text = util.unescape(value)
+            multi = (value.split("<")[0] != value)
 
             for Item in items:
                 if Item.tags and row[TAG] not in Item.tags: continue
@@ -468,7 +470,8 @@ class EditTags(gtk.VBox):
                 else:
                     b.connect('activate', self.__menu_activate, view)
 
-                    if not min(map(self.__songinfo.can_change, b.needs)+[1]):
+                    if not min(map(self.__songinfo.can_change, b.needs)+[1]) \
+                        or multi:
                         b.set_sensitive(False)
 
                     menu.append(b)
@@ -571,7 +574,7 @@ class EditTags(gtk.VBox):
                 renamed[row[TAG]].append((util.decode(row[ORIGTAG]),
                                           util.decode(row[VALUE]),
                                           util.decode(row[ORIGVALUE])))
-                
+
         was_changed = []
         songs = self.__songinfo.songs
         win = WritingWindow(self, len(songs))
@@ -679,7 +682,7 @@ class EditTags(gtk.VBox):
             msg = _("Invalid tag <b>%s</b>\n\nThe files currently"
                     " selected do not support editing this tag."
                     ) % util.escape(row[TAG])
-            qltk.ErrorMessage(self, title, msg).run()            
+            qltk.ErrorMessage(self, title, msg).run()
         elif not self.__songinfo.can_change(new_tag):
             # Can't add the new tag.
             title = _("Invalid tag")
