@@ -156,10 +156,10 @@ class OneSong(qltk.Notebook):
         w.set_ellipsize(pango.ELLIPSIZE_END)
         hb = gtk.HBox(spacing=12)
 
-        cover = CoverImage([70, 70], song)
+        cover = CoverImage(song=song)
         if cover: hb.pack_start(cover, expand=False)
         else: cover.destroy()
-                            
+
         hb.pack_start(w)
         box.pack_start(Frame(tag("album"), hb), expand=False, fill=False)
 
@@ -218,7 +218,7 @@ class OneSong(qltk.Notebook):
     def _library(self, song, box):
         def counter(i):
             if i == 0: return _("Never")
-            else: return ngettext("%d time", "%d times", i) % i
+            else: return ngettext("%(n)d time", "%(n)d times", i) % {"n": i}
         def ftime(t):
             if t == 0:
                 return _("Unknown")
@@ -261,11 +261,13 @@ class OneSong(qltk.Notebook):
                 return timestr.decode(const.ENCODING)
 
         fn = util.fsdecode(util.unexpand(song["~filename"]))
-        length = util.format_time_long(song["~#length"])
-        size = util.format_size(util.size(song["~filename"]))
+        length = util.format_time_long(song.get("~#length", 0))
+        size = util.format_size(
+            song.get("~#filesize") or util.size(song["~filename"]))
         mtime = ftime(util.mtime(song["~filename"]))
-        if "~#bitrate" in song and song["~#bitrate"] != 0:
-            bitrate = _("%d kbps") % int(song["~#bitrate"])
+        bitrate = song.get("~#bitrate", 0)
+        if bitrate != 0:
+            bitrate = _("%d kbps") % int(bitrate)
         else: bitrate = False
 
         t = gtk.Table(4, 2)
@@ -327,7 +329,7 @@ class OneAlbum(qltk.Notebook):
                     song("~#track", discs.get(song("~#disc"), 0))])
         tracks = sum(discs.values())
         discs = len(discs)
-        length = sum([song["~#length"] for song in songs])
+        length = sum([song.get("~#length", 0) for song in songs])
 
         if tracks == 0 or tracks < len(songs): tracks = len(songs)
 
@@ -359,7 +361,7 @@ class OneAlbum(qltk.Notebook):
         w.set_markup("\n".join(text))
         hb = gtk.HBox(spacing=12)
 
-        cover = CoverImage([70, 70], song)
+        cover = CoverImage(song=song)
         if cover: hb.pack_start(cover, expand=False)
         else: cover.destroy()
 
@@ -472,7 +474,7 @@ class OneArtist(qltk.Notebook):
         added = set()
         for i, (album, cover, song) in enumerate(covers):
             if cover.name in added: continue
-            cov = CoverImage([70, 70], song)
+            cov = CoverImage(song=song)
             cov.child.set_tooltip_text(album)
             c = i % 4
             r = i // 4
@@ -538,7 +540,7 @@ class ManySongs(qltk.Notebook):
         time = 0
         size = 0
         for song in songs:
-            time += song["~#length"]
+            time += song.get("~#length", 0)
             try: size += util.size(song["~filename"])
             except EnvironmentError: pass
         table = gtk.Table(2, 2)
