@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright 2004-2010 Joe Wreschnig, Michael Urman, Iñigo Serna,
-#                     Steven Robertson
+#                     Steven Robertson, Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,7 +18,7 @@ from quodlibet import util
 from quodlibet.parse import Query
 from quodlibet.qltk.ccb import ConfigCheckButton
 from quodlibet.qltk.chooser import FolderChooser
-from quodlibet.qltk.entry import ValidatingEntry
+from quodlibet.qltk.entry import ValidatingEntry, UndoEntry
 from quodlibet.qltk.songlist import SongList
 
 class PreferencesWindow(qltk.UniqueWindow):
@@ -80,7 +80,7 @@ class PreferencesWindow(qltk.UniqueWindow):
             hbox = gtk.HBox(spacing=6)
             l = gtk.Label(_("_Others:"))
             hbox.pack_start(l, expand=False)
-            others = gtk.Entry()
+            others = UndoEntry()
             if "~current" in checks: checks.remove("~current")
             others.set_text(" ".join(checks))
             others.set_tooltip_text(
@@ -155,11 +155,11 @@ class PreferencesWindow(qltk.UniqueWindow):
             self.pack_start(f, expand=False)
 
             c1 = ConfigCheckButton(
-                _("Confirm _multiple ratings"), 
+                _("Confirm _multiple ratings"),
                 'browsers', 'rating_confirm_multiple')
             c1.set_active(
                 config.getboolean("browsers", "rating_confirm_multiple"))
-            c1.set_tooltip_text(_("Ask for confirmation before changin the "
+            c1.set_tooltip_text(_("Ask for confirmation before changing the "
                      "rating of multiple songs at once"))
 
             c2 = ConfigCheckButton(
@@ -167,7 +167,7 @@ class PreferencesWindow(qltk.UniqueWindow):
                'browsers', 'rating_click')
             c2.set_active(
                 config.getboolean("browsers", "rating_click"))
-            c2.set_tooltip_text(_("Enable rating by clicking on the rating  "
+            c2.set_tooltip_text(_("Enable rating by clicking on the rating "
                      "column in the song list"))
 
             vbox = gtk.VBox(spacing=6)
@@ -175,7 +175,7 @@ class PreferencesWindow(qltk.UniqueWindow):
             vbox.pack_start(c2, expand=False)
 
             f1 = qltk.Frame(_("Ratings"), child=vbox)
-            self.pack_start(f1, expand=False)          
+            self.pack_start(f1, expand=False)
 
         def _entry(self, entry, name, section="settings"):
             config.set(section, name, entry.get_text())
@@ -187,7 +187,7 @@ class PreferencesWindow(qltk.UniqueWindow):
             self.title = _("Player")
 
             if config.get('player', 'backend') == "gstbe":
-                e = gtk.Entry()
+                e = UndoEntry()
                 e.set_tooltip_text(_("The GStreamer output pipeline used for "
                         "playback, such as 'alsasink device=default'. "
                         "Leave blank for default pipeline."))
@@ -244,7 +244,7 @@ class PreferencesWindow(qltk.UniqueWindow):
 
             hb = gtk.HBox(spacing=6)
             hb.pack_start(l, expand=False)
-            hb.pack_start(s)
+            hb.pack_start(s, expand=False)
             vbox.pack_start(hb, expand=False)
             try:
                 pre_amp_gain = config.getfloat("player", "pre_amp_gain")
@@ -262,7 +262,7 @@ class PreferencesWindow(qltk.UniqueWindow):
             l.set_mnemonic_widget(s)
             hb = gtk.HBox(spacing=6)
             hb.pack_start(l, expand=False)
-            hb.pack_start(s)
+            hb.pack_start(s, expand=False)
             vbox.pack_start(hb, expand=False)
             f = qltk.Frame(_("Replay Gain Volume Adjustment"), child=vbox)
             self.pack_start(f)
@@ -282,7 +282,7 @@ class PreferencesWindow(qltk.UniqueWindow):
             self.title = _("Library")
             hb = gtk.HBox(spacing=6)
             b = qltk.Button(_("_Select"), gtk.STOCK_OPEN)
-            e = gtk.Entry()
+            e = UndoEntry()
             e.set_text(util.fsdecode(config.get("settings", "scan")))
             hb.pack_start(e)
             e.set_tooltip_text(_("Songs placed in these folders (separated "
@@ -309,7 +309,7 @@ class PreferencesWindow(qltk.UniqueWindow):
 
             vbox = gtk.VBox(spacing=6)
             hb = gtk.HBox(spacing=6)
-            e = gtk.Entry()
+            e = UndoEntry()
             e.set_text(config.get("editing", "split_on"))
             e.connect('changed', self.__changed, 'editing', 'split_on')
             e.set_tooltip_text(_('Separators for splitting tags'))
@@ -320,6 +320,12 @@ class PreferencesWindow(qltk.UniqueWindow):
             hb.pack_start(e)
             vbox.pack_start(hb, expand=False)
 
+            cb = ConfigCheckButton(
+                _("Enable _human title case"), 'editing', 'human_title_case')
+            cb.set_active(config.getboolean("editing", 'human_title_case'))
+            cb.set_tooltip_text(_("Uses common English rules for title casing, as in \"Dark Night of the Soul\""))
+            vbox.pack_start(cb, expand=False)
+
             vb2 = gtk.VBox(spacing=0)
             cb = ConfigCheckButton(
                 _("Save ratings and play _counts"), "editing", "save_to_songs")
@@ -327,7 +333,7 @@ class PreferencesWindow(qltk.UniqueWindow):
             vb2.pack_start(cb)
             hb = gtk.HBox(spacing=3)
             lab = gtk.Label(_("_Email:"))
-            entry = gtk.Entry()
+            entry = UndoEntry()
             entry.set_tooltip_text(_("Ratings and play counts will be set "
                                      "for this email address"))
             entry.set_text(config.get("editing", "save_email"))
