@@ -787,8 +787,13 @@ class SongList(AllTreeView, util.InstanceTracker):
 
         star = list(Query.STAR)
         for header in headers:
-            if not header.startswith("~#") and header not in star:
-                star.append(header)
+            if "<" in header:
+                tags = Pattern(header).tags
+            else:
+                tags = util.tagsplit(header)
+            for tag in tags:
+                if not tag.startswith("~#") and tag not in star:
+                    star.append(tag)
         SongList.star = star
 
     set_all_column_headers = classmethod(set_all_column_headers)
