@@ -1,14 +1,14 @@
-import gobject, gtk
 from tests import TestCase, add
 
-import widgets
-from player import PlaylistPlayer
-from browsers.iradio import InternetRadio
-from qltk.watcher import SongWatcher
+from quodlibet.library import SongLibrary
+from quodlibet.browsers.iradio import InternetRadio
+from quodlibet.player.nullbe import NullPlayer
+import quodlibet.config
 
 class TInternetRadio(TestCase):
     def setUp(self):
-        self.bar = InternetRadio(SongWatcher(), PlaylistPlayer('fakesink'))
+        quodlibet.config.init()
+        self.bar = InternetRadio(SongLibrary(), NullPlayer())
 
     def test_can_filter(self):
         for key in ["foo", "title", "fake~key", "~woobar", "~#huh"]:
@@ -16,4 +16,5 @@ class TInternetRadio(TestCase):
 
     def tearDown(self):
         self.bar.destroy()
+        quodlibet.config.quit()
 add(TInternetRadio)
