@@ -28,11 +28,11 @@ class TVCFile(TestCase):
         config.set("editing", "save_email", "foo@bar.org")
         self.song["~#rating"] = 0.2
         self.song.write()
-        self.song["~#rating"] = 0.5
+        self.song["~#rating"] = const.DEFAULT_RATING
         self.song.write()
         song = type(self.song)(self.filename)
         config.set("editing", "save_email", const.EMAIL)
-        self.failUnlessEqual(song["~#rating"], 0.5)
+        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
 
     def test_new_email_rating(self):
         config.set("editing", "save_email", "foo@bar.org")
@@ -56,7 +56,7 @@ class TVCFile(TestCase):
         self.song.write()
         config.set("editing", "save_email", const.EMAIL)
         song = type(self.song)(self.filename)
-        self.failUnlessEqual(song["~#rating"], 0.5)
+        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
 
         song.write()
         config.set("editing", "save_email", "foo@bar.org")
@@ -68,7 +68,7 @@ class TVCFile(TestCase):
         self.song["~#rating"] = "invalid"
         self.song.write()
         song = type(self.song)(self.filename)
-        self.failUnlessEqual(song["~#rating"], 0.5)
+        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
 
     def test_huge_playcount(self):
         count = 1000000000000000L
@@ -103,7 +103,7 @@ class TVCFile(TestCase):
         self.song.write()
         song = type(self.song)(self.filename)
         config.set("editing", "save_to_songs", "true")
-        self.failUnlessEqual(song["~#rating"], 0.5)
+        self.failUnlessEqual(song("~#rating"), const.DEFAULT_RATING)
 
     def test_can_change(self):
         self.failUnless(self.song.can_change())
