@@ -1,8 +1,9 @@
-import os, gtk
-from tests import add, TestCase
-from qltk.completion import EntryWordCompletion, LibraryTagCompletion
-from qltk.watcher import SongWatcher
-from library import Library
+from tests import TestCase, add
+
+import gtk
+
+from quodlibet.library import SongLibrary
+from quodlibet.qltk.completion import EntryWordCompletion, LibraryTagCompletion
 
 class TEntryWordCompletion(TestCase):
     def test_ctr(self):
@@ -16,11 +17,10 @@ add(TEntryWordCompletion)
 
 class TLibraryTagCompletion(TestCase):
     def test_ctr(self):
-        w = LibraryTagCompletion(SongWatcher(), Library()).destroy()
+        w = LibraryTagCompletion(SongLibrary())
         e = gtk.Entry()
         e.set_completion(w)
         self.failUnlessEqual(w.get_entry(), e)
         self.failUnlessEqual(e.get_completion(), w)
         e.destroy()
-add(TEntryWordCompletion)
-    
+add(TLibraryTagCompletion)
