@@ -1,8 +1,11 @@
-from tests import add, TestCase
-from qltk.downloader import DownloadWindow
+from tests import TestCase, add
+
+from quodlibet.qltk.downloader import DownloadWindow
+import quodlibet.config
 
 class TDownloadWindow(TestCase):
     def setUp(self):
+        quodlibet.config.init()
         self.win = DownloadWindow()
 
     def test_ctr(self):
@@ -10,4 +13,5 @@ class TDownloadWindow(TestCase):
 
     def tearDown(self):
         self.win.destroy()
+        quodlibet.config.quit()
 add(TDownloadWindow)
